@@ -11,15 +11,17 @@ class UnitSystem(AutoEnum):
 
     - the decimal system where powers of 10 (factor: 10^3) are used
     - the binary system where powers of 2 (factor: 2^10) are used
+    - no system where higher units are not used
 
     This enum lists these possibilities.
     """
 
     BINARY = auto()
     DECIMAL = auto()
+    NONE = auto()
 
 
-def get_base_and_pad_and_units(us: UnitSystem) -> [int, list[str]]:
+def get_base_and_pad_and_units(us: UnitSystem) -> tuple[int, int, list[str]]:
     """
     Get the base factor i.e. the ratio between any two successive orders of
     magnitude and the units corresponding to each multiplication of the base
